# MiUpload Library
MiUpload library is small lighweight library for collecting and distribution of jupyter notebooks during Structured Study Sessions on Minerva Schools at KGI.

Learn more about Minerva on <https://minerva.kgi.edu>
    